%define anolis_release 5

Name:           star
Version:        1.6
Release:        %{anolis_release}%{?dist}
Summary:        An archiving tool with ACL support
License:        CDDL
URL:            https://sourceforge.net/projects/s-tar/
Source0:        https://downloads.sourceforge.net/s-tar/%{name}-%{version}.tar.bz2
Patch0: 	0000-star-1.6-star-mk.patch
Patch1: 	0001-star-1.5.2-bufferoverflow.patch
Patch2: 	0002-star-1.6-manpagereferences.patch
Patch3: 	0003-star-1.5.2-use-ssh-by-default.patch

BuildRequires: 	make libattr-devel libacl-devel libtool libselinux-devel e2fsprogs-devel

%description
Star saves many files together into a single tape or disk archive,
and can restore individual files from the archive. Star supports ACL.

%package -n     scpio
Summary:        Copy file archives in and out (LEGACY)

%description -n scpio
The %{name}-scpio package contains the scpio utility, depending on the options
used: copies files to an archive file, extracts files from an archive file,
lists files from an archive file or copies files from one directory tree to
another.

%package -n     rmt
Summary: Provides certain programs with access to remote tape devices
Epoch:          2

%description -n rmt
The %{name}-rmt package contains the rmt utility provides remote access to
tape devices for programs like dump (a filesystem backup program), restore
(a program for restoring files from a backup), and tar (an archiving program).

%package -n     spax
Summary:        Portable archive exchange
Requires(post):  %{_sbindir}/update-alternatives
Requires(preun): %{_sbindir}/update-alternatives

%description -n spax
The %{name}-spax package contains the pax utility shall read and write archives,
write lists of the members of archive files and copy directory hierarchies as
is defined in IEEE Std 1003.1.

%package doc
Summary:        Documentation files for %{name}
Requires:       %{name} = %{version}-%{release}
BuildArch:      noarch

%description    doc
The %{name}-doc package contains documentation files for %{name}.

%prep
%autosetup -n %{name}-%{version} -p1

cp -a star/all.mk star/Makefile

star_recode()
{
    for i in $@; do
        iconv -f iso_8859-1 -t utf-8 $i > .tmp_file
        mv .tmp_file $i
    done
}

star_recode AN-1.5 AN-1.5.2 star/star.4

for PLAT in %{arm} %{power64} aarch64 %{mips} x86_64 s390 s390x sh3 sh4 sh4a sparcv9 loongarch64; do
    for AFILE in gcc cc; do
            [ ! -e RULES/${PLAT}-linux-${AFILE}.rul ] \
            && ln -s i586-linux-${AFILE}.rul RULES/${PLAT}-linux-${AFILE}.rul
    done
done

%build
%global make_flags GMAKE_NOWARN=true                                    \\\
    RUNPATH=                                                            \\\
    LDPATH=                                                             \\\
    PARCH=%{_target_cpu}                                                \\\
    K_ARCH=%{_target_cpu}                                               \\\
    INS_BASE=$RPM_BUILD_ROOT%{_prefix}                                  \\\
    INS_RBASE=$RPM_BUILD_ROOT                                           \\\
    INSTALL='sh $(SRCROOT)/conf/install-sh -c -m $(INSMODEINS)'         \\\
    COPTX="$RPM_OPT_FLAGS -DTRY_EXT2_FS"                                \\\
    LDOPTX="$RPM_LD_FLAGS"                                              \\\
    DEFCCOM=gcc

make %make_flags

%install
make install -s %make_flags

ln -s star.1 ${RPM_BUILD_ROOT}%{_mandir}/man1/ustar.1
mkdir -p ${RPM_BUILD_ROOT}%{_sysconfdir}
mkdir -p ${RPM_BUILD_ROOT}%{_pkgdocdir}
ln -s %{_sbindir}/rmt ${RPM_BUILD_ROOT}%{_sysconfdir}/rmt
install -p -m 644 COPYING star/README  CDDL.Schily.txt AN-* \
    ${RPM_BUILD_ROOT}%{_pkgdocdir}

( cd ${RPM_BUILD_ROOT}
  rm -f .%{_bindir}/mt
  rm -f .%{_bindir}/smt
  rm -f .%{_bindir}/tartest
  rm -f .%{_bindir}/tar
  rm -f .%{_bindir}/gnutar
  rm -f .%{_bindir}/star_fat
  rm -f .%{_bindir}/star_sym
  rm -f .%{_bindir}/suntar
  rm -f .%{_sysconfdir}/default/star
  rm -rf .%{_prefix}%{_sysconfdir}
  rm -rf .%{_prefix}/include
  rm -rf .%{_prefix}/lib # hard-wired intently
  rm -rf .%{_mandir}/man3
  rm -rf .%{_mandir}/man5/{makefiles,makerules}.5*
  rm -rf .%{_mandir}/man1/{tartest,gnutar,smt,mt,suntar,match}.1*
  rm -rf .%{_docdir}/star/testscripts
  rm -rf .%{_docdir}/star/TODO
  rm -rf .%{_docdir}/rmt
)

%global general_docs \
%dir %{_pkgdocdir} \
%doc %{_pkgdocdir}/COPYING \
%doc %{_pkgdocdir}/CDDL.Schily.txt \

%post -n 	spax
%{_sbindir}/update-alternatives \
    --install %{_bindir}/pax pax %{_bindir}/spax 66 \
    --slave %{_mandir}/man1/pax.1%{_extension} pax.1%{_extension} %{_mandir}/man1/spax.1%{_extension}

%preun -n 	spax
if [ $1 -eq 0 ]; then
    %{_sbindir}/update-alternatives --remove pax %{_bindir}/spax
fi

%files
%license COPYING
%doc %{_pkgdocdir}
%{_bindir}/star
%{_bindir}/ustar
%{_mandir}/man1/star.1*
%{_mandir}/man1/star_sym.1*
%{_mandir}/man1/ustar.1*
%{_mandir}/man5/star.5*

%files -n scpio
%dir %{_pkgdocdir}
%license COPYING
%doc %{_pkgdocdir}/CDDL.Schily.txt 
%doc %{_mandir}/man1/scpio.1*
%{_bindir}/scpio

%files -n rmt
%dir %{_pkgdocdir}
%license COPYING
%doc %{_pkgdocdir}/CDDL.Schily.txt
%{_sbindir}/rmt
%{_mandir}/man1/rmt.1*
%config %{_sysconfdir}/default/rmt
%{_sysconfdir}/rmt

%files -n spax
%dir %{_pkgdocdir}
%license COPYING
%doc %{_pkgdocdir}/CDDL.Schily.txt
%doc %{_mandir}/man1/spax.1*
%{_bindir}/spax
%ghost %verify(not md5 size mode mtime) %{_bindir}/pax
%ghost %verify(not md5 size mode mtime) %{_mandir}/man1/pax.1%{_extension}

%files doc
%doc README*

%changelog
* Thu Oct 12 2023 Wenlong Zhang<zhangwenlong@loongson.cn> - 1.6-5
- fix build error for loongarch64

* Fri May 05 2023 Funda Wang <fundawang@yeah.net> - 1.6-4
- Fix requires on different epoch

* Fri Apr 14 2023 Kaihao Bai <carlo.bai@linux.alibaba.com> - 1.6-3
- optimize spec

* Mon Jan 16 2023 Funda Wang <fundawang@yeah.net> - 1.6-2
- Use man page extesion macro defined in new system-rpm-config

* Tue Apr 19 2022 happy_orange <songnannan@linux.alibaba.com> - 1.6-1
- Init package from upstream
